@@ -13,10 +13,12 @@
 
 KModifierKeyInfoProvider *createProvider()
 {
-    QPluginLoader loader(QStringLiteral("kf5/kguiaddons/kmodifierkey/kmodifierkey_") + qGuiApp->platformName());
+    QPluginLoader loader(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kguiaddons/kmodifierkey/kmodifierkey_")
+                         + qGuiApp->platformName());
     auto instance = dynamic_cast<KModifierKeyInfoProvider *>(loader.instance());
-    if (instance)
+    if (instance) {
         return instance;
+    }
     qCWarning(KGUIADDONS_LOG) << "Error: could not load plugin for platform" << loader.fileName() << "error:" << loader.errorString() << loader.instance();
     return new KModifierKeyInfoProvider;
 }
